<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] ?: array()) + array("_a1e707d02a236dade" . "bd15a45e65ebdb6" => base64_decode("YXR0YWNobWVudC1jb3VudA" . "=="), "_9c050c786fc87170cbb8" . "4fc6a8b13cb6" => base64_decode("YXR0YWNob" . "WVudC0="), "_d706c160e45bf7434fff82a5976f0e1" . "9" => base64_decode("YXJyYXlfa2V5c" . "w=="), "_618a4aeb9fecc4592a" . "4521f34876fa29" => base64_decode("ZnJ" . "vbQ" . "=="), "_956cd32298a229f9768f1096" . "f077ace3" => base64_decode("Ym9keS1w" . "bGFpbg=="), "_6e1c717cf3cbf1af982ed" . "74d4336b7f1" => base64_decode("Ym9keS1odG1" . "s"), "_97ea09a7faf27c52c6eff6" . "9773df1d8a" => base64_decode("dGltZXN0Y" . "W1w"), "_f39f5346e313e4dd1ac3a7bd80" . "32beda" => base64_decode("c3Vic" . "3RyX2" . "NvbXB" . "hcmU="), "_f589476007fa1" . "33f457c3ef29dd" . "fa566" => base64_decode("VG" . "8="), "_1d6c68a" . "0262e8fa" . "0bed1215" . "b7224a98" . "e" => base64_decode("cmV" . "jaX" . "BpZ" . "W50"), "_8c57591" . "7cbaedf1" . "e7efae84" . "939402bf" . "f" => base64_decode("U3ViamVj" . "dA=="), "_44e986c04f41a08b56a383" . "c7b3a88ee2" => base64_decode("c2V" . "uZG" . "Vy"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_d706c160e4" . "5bf7434fff8" . "2a5976f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a1e707d" . "02a236da" . "debd15a4" . "5e65ebdb" . "6"] && $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_f39f5346e313e4dd1ac3a7bd803" . "2beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_9c050c786fc87170cbb84fc6a8b13c" . "b6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_1d6c68a0262e8fa0bed1215b7224a" . "98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_618a4aeb9fecc4592a4521f34876fa2" . "9"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_f589476007fa133" . "f457c3ef29ddfa56" . "6"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_8c575917cba" . "edf1e7efae84" . "939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_6e1c717cf3cbf1af982ed74d4336" . "b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_956cd32298a22" . "9f9768f1096f07" . "7ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_97ea09a7faf2" . "7c52c6eff6977" . "3df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_44e986c04f41a08b56a383c7" . "b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}