<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_e608e5b5c4c34a" . "67ba97ef84c1e16" . "199" => base64_decode("J" . "w" . "=" . "="), "_c35473364fa7a050" . "299058f332ec29c1" => base64_decode("ZXhjZXB0a" . "W9u"), "_460e1aeb311" . "3a1676ce59a8" . "f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jY" . "XB0dXJlIHByb2plY3Q="), "_376d30c4" . "0857357a4" . "d4cbb1ffa" . "a25817" => base64_decode("dG" . "8="), "_f656816961e85738061" . "41c558b184fe2" => base64_decode("c3ViamV" . "jdA=="), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJv" . "bQ=="), "_5d40a2cf1c525fb252bf5599e3" . "39fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbn" . "RpZmllZCBmb3IgbWFpbDsgc3ViamVjdCAn"), "_ced92d7b391285c8" . "a26846f1f4bd3128" => base64_decode("Ym9keV" . "90ZXh0"), "_03b1f0cee835582d1158dce2678b" . "505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJz" . "Y3JpYmVy"), "_bfda889b74ea561b14325" . "e30e7d75426" => base64_decode("Ym9keV" . "9odG1s"), "_67a0d624aebcceb0abd5ce5" . "6a53ff06f" => base64_decode("ZGF0ZQ" . "=="), "proje" . "ct_id" => base64_decode("cHJvamV" . "jdF9pZA" . "=="), "_a3d82c5df38e194c9c7" . "3e3ccb4223bbc" => base64_decode("ZW1ha" . "WxfZG" . "F0YQ=" . "="), "_9b16fa2683095e67d7c8b2" . "65a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZWNlaX" . "Zlcg=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_9b16fa2683095e67" . "d7c8b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_03b1f0cee835582d1158dce2678b505" . "c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_5d40a2cf1c525fb252bf5599e3" . "39fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_e608e5b5c4c34a67" . "ba97ef84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_618a4aeb9fecc4592a4521f" . "34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_376d30c40857357a4d4cbb1ffaa258" . "17"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f656816961e8573806" . "141c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_ced92d7b391285c8a26" . "846f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_bfda889b" . "74ea561b1" . "4325e30e7" . "d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_67a0d624ae" . "bcceb0abd5c" . "e56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_460e1aeb3113a1676ce5" . "9a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["proj" . "ect_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a3d82c5df38e194c9c73e3" . "ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_c35473364fa7a050299058f" . "332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}